<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 11/12/2008	ELL
// Fixed bug with custom tags using "#" instead of ".".
// Revised: 7/30/2009	ELL
// Added field `subclass_sort_order` with a default of 500.  This will be used to arrange the classes when defining class/subclass relationships.
// Revised: 8/1/2009	ELL
// Added ability to operate using different class tables.  This was done to give the ability
// to style calendar grids and event grids without adding 14 more classes to the site style list.
// Renamed from add_tag.php to add_class.php.
// Added feed thru to show/hide custom styles.
// Revised: 1/27/2010	ELL
// Removed line that replaces spaces with underscores.  This had some purpose once upon a time, but no longer has a reason.
// Add trimming of white space on outside of class.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
// Revised: 2/13/2013	ELL
// Added handling of new class/ID dropdown as class_prefix.
// Modified: 12/2/2016	ELL
// Consolidated all class tables into site_classes table indexed by style_sheet field.
// Consolidated all CSS tables into site_css table indexed by style_sheet field.
// Modified: 11/14/2017	ELL
// Added checking between class prefix and class to avoid redundancy and inconsistency.
// 
// 
	include ("check_session.php");

	$style_sheet = $_REQUEST['style_sheet'];

	$class = trim($_POST['class']);
	$class_prefix = $_POST['class_prefix'];
	
	if (isset($class_prefix) && ($class_prefix != "") && (substr($class, 0, 1) != "#") && (substr($class, 0, 1) != "."))
		$class = $class_prefix . $class;
	elseif (isset($class_prefix) && ($class_prefix != "") && ((substr($class, 0, 1) == "#") || (substr($class, 0, 1) == ".")))
		$class = $class_prefix . substr($class, 1);
		
	$search = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
	$replace = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
	$class_str = str_replace($search, $replace, $class);
	$_SESSION['last_class_edited'] = $class_str;
	$description = addslashes($_POST['description']);
	$sort_order = $_POST['sort_order'];
	
	//First check to see if user exists.
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' AND `class` = '$class'";
	$result = $bwb_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$tmp_class = $row["class"];
	if ($tmp_class)
	{
		echo ERROR_CAPS_WORD . ": '$class' " . CLASSES_ADD_CLASS_ADD_ERR;
		exit;
	}
	
	
	// Add class to database.
	$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "site_classes` SET `style_sheet` = '$style_sheet', `class` = '$class', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
	$cnt = $bwb_dbh->exec($query);
	
	echo 1;
?>
